@@ -714,8 +714,9 @@ class SoftwareProperties(object):
     """
     Add a source for the given line.
     """
-    return self.add_source_from_shortcut(shortcut=shortcut_handler(line),
-                                         enable_source_code=enable_source_code)
+    return self.add_source_from_shortcut(
+        shortcut=shortcut_handler(line.strip()),
+        enable_source_code=enable_source_code)
 
   def add_source_from_shortcut(self, shortcut, enable_source_code=False):
     """
