@@ -21,15 +21,15 @@
 #  USA
 
 import os
-import subprocess
-import thread
-import time
-import gobject
-import gtk
-import apt_pkg
+from gi.repository import GObject, Gtk
+
+import aptdaemon.client
+import aptdaemon.enums
+from aptdaemon.gtk3widgets import AptErrorDialog, AptProgressDialog
 
 from softwareproperties.gtk.utils import *
 
+
 class DialogCacheOutdated:
     def __init__(self, parent, datadir):
         """setup up the gtk dialog"""
@@ -39,32 +39,44 @@ class DialogCacheOutdated:
         self.dialog = self.dialog_cache_outofdate
         self.dialog.set_transient_for(parent)
 
-    def update_cache(self, window_id, lock):
-        """start synaptic to update the package cache"""
+    def _run_transaction(self, transaction):
+        transaction.connect('finished', self._on_transaction_done)
+        dia = AptProgressDialog(transaction) #parent=self.parent.get_window())
+        dia.run(close_on_finished=True, show_error=True,
+                reply_handler=lambda: True,
+                error_handler=self._on_error)
+
+    def _on_transaction_done(self, transaction, exit_state):
+        self.loop.quit()
+
+    def _on_error(self, error):
         try:
-            apt_pkg.pkgsystem_unlock()
-        except SystemError:
+            raise error
+        except aptdaemon.errors.NotAuthorizedError:
+            # Silently ignore auth failures
+            return
+        except aptdaemon.errors.TransactionFailed as error:
             pass
-        cmd = ["/usr/sbin/synaptic", "--hide-main-window",
-               "--non-interactive",
-               "--parent-window-id", "%s" % (window_id),
-               "--update-at-startup"]
-        subprocess.call(cmd)
-        lock.release()
+        except Exception as error:
+            error = aptdaemon.errors.TransactionFailed(aptdaemon.enums.ERROR_UNKNOWN,
+                                                       str(error))
+        dia = AptErrorDialog(error)
+        dia.run()
+        dia.hide()
 
     def run(self):
-        """run the dialog, and if reload was pressed run synaptic"""
+        """run the dialog, and if reload was pressed run cache update"""
         res = self.dialog.run()
         self.dialog.hide()
-        if res == gtk.RESPONSE_APPLY:
+        if res == Gtk.ResponseType.APPLY:
+            self.loop = GObject.MainLoop()
+
+            ac = aptdaemon.client.AptClient()
+            ac.update_cache(reply_handler=self._run_transaction,
+                            error_handler=self._on_error)
+
             self.parent.set_sensitive(False)
-            lock = thread.allocate_lock()
-            lock.acquire()
-            t = thread.start_new_thread(self.update_cache,
-                                       (self.parent.window.xid, lock))
-            while lock.locked():
-                while gtk.events_pending():
-                    gtk.main_iteration()
-                time.sleep(0.05)
+            self.loop.run()
             self.parent.set_sensitive(True)
+
         return res
