@@ -22,8 +22,9 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 #  USA
 
+from __future__ import print_function
+
 import os
-import gobject
 from gi.repository import Gtk
 
 from aptsources.sourceslist import SourceEntry
@@ -45,7 +46,7 @@ class DialogEdit:
     elif source_entry.type == "deb-src":
       self.combobox_type.set_active(1)
     else:
-      print "Error, unknown source type: '%s'" % source_entry.type
+      print("Error, unknown source type: '%s'" % source_entry.type)
 
     # uri
     self.entry_uri.set_text(source_entry.uri)
@@ -121,10 +122,7 @@ class DialogEdit:
         # change repository
         index = self.sourceslist.list.index(self.source_entry)
         file = self.sourceslist.list[index].file
-        self.sourceslist.list[index] = SourceEntry(line,file)
-        #self.sourceslist.add(self.selected.type,
-        #                     self.selected.uri,
-        #                     self.selected.dist,
-        #                     self.selected_comps)
+        self.new_source_entry = SourceEntry(line,file)
+        self.sourceslist.list[index] = self.new_source_entry
       self.main.hide()
       return res
