@@ -128,7 +128,7 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
         # gsettings
         all_schemas = Gio.Settings.list_schemas()
         if "com.ubuntu.update-notifier" in all_schemas:
-            self.settings = Gio.Settings("com.ubuntu.update-notifier")
+            self.settings = Gio.Settings.new("com.ubuntu.update-notifier")
             # we need this for reverting
             self.initial_auto_launch = self.settings.get_int("regular-auto-launch-interval")
         else:
@@ -312,7 +312,7 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
             #              first %s is the description of the component
             #              second %s is the code name of the comp, eg main, universe
             label = _("%s (%s)") % (comp.get_description(), comp.name)
-            checkbox = Gtk.CheckButton(label)
+            checkbox = Gtk.CheckButton(label=label)
 
             checkbox.comp = comp
             # setup the callback and show the checkbutton
@@ -782,7 +782,6 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
         """The config was changed and now needs to be saved and reloaded"""
         apt.apt_pkg.init_config()
         self.button_revert.set_sensitive(True)
-        self.modified_sourceslist = True
 
     def on_keys_modified(self):
         """ The apt keys have changed and need to be redisplayed """
@@ -1119,8 +1118,8 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
 
         props = {"halign":Gtk.Align.CENTER, "valign":Gtk.Align.CENTER,
                  "vexpand":True, "visible":True}
-        self.label_driver_detail = Gtk.Label(_("Searching for available "
-                                               "drivers..."), **props)
+        self.label_driver_detail = Gtk.Label(label=_("Searching for available "
+                                                     "drivers..."), **props)
         self.box_driver_detail.add(self.label_driver_detail)
 
         self.progress_bar = Gtk.ProgressBar()
@@ -1259,7 +1258,10 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
             try:
                 pkg = self.apt_cache[pkg_driver_name]
                 installed = pkg.is_installed
-                description = _("Using {} from {}").format(pkg.candidate.summary, pkg.shortname)
+                if pkg.candidate is not None:
+                    description = _("Using {} from {}").format(pkg.candidate.summary, pkg.shortname)
+                else:
+                    description = _("Using {}").format(pkg.shortname)
             except KeyError:
                 print("WARNING: a driver ({}) doesn't have any available package associated: {}".format(pkg_driver_name, current_driver))
                 continue
@@ -1331,10 +1333,10 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
             device_detail = Gtk.Box(spacing=6, orientation=Gtk.Orientation.VERTICAL)
             device_box.pack_start(device_detail, True, True, 0)
 
-            widget = Gtk.Label("{}: {}".format(self.devices[device].get('vendor', _('Unknown')), self.devices[device].get('model', _('Unknown'))))
+            widget = Gtk.Label.new("{}: {}".format(self.devices[device].get('vendor', _('Unknown')), self.devices[device].get('model', _('Unknown'))))
             widget.set_halign(Gtk.Align.START)
             device_detail.pack_start(widget, True, False, 0)
-            widget = Gtk.Label("<small>{}</small>".format(overall_status))
+            widget = Gtk.Label.new("<small>{}</small>".format(overall_status))
             widget.set_halign(Gtk.Align.START)
             widget.set_use_markup(True)
             device_detail.pack_start(widget, True, False, 0)
