@@ -1,5 +1,6 @@
 #!/usr/bin/python
 
+import os
 import unittest
 import sys
 sys.path.insert(0, "..")
@@ -26,6 +27,9 @@ MOCK_PPA_INFO={
 
 class LaunchpadPPATestCase(unittest.TestCase):
 
+    @unittest.skipUnless(
+        "TEST_ONLINE" in os.environ,
+        "skipping online tests unless TEST_ONLINE environment variable is set")
     def test_ppa_info_from_lp(self):
         # use correct data
         info = softwareproperties.ppa.get_ppa_info_from_lp("mvo", "ppa")
